@@ -172,8 +172,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
     QCoreApplication app(argc, argv);
 
     if (argc != 4) {
-        qCDebug(KIO_FILENAMESEARCH) << "Usage: kio_filenamesearch protocol domain-socket1 domain-socket2"
-                                    << endl;
+        qCDebug(KIO_FILENAMESEARCH) << "Usage: kio_filenamesearch protocol domain-socket1 domain-socket2";
         return -1;
     }
 
